@@ -9,7 +9,7 @@ package Rex::Report::YAML;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.3'; # VERSION
 
 use Rex;
 use Data::Dumper;
@@ -20,6 +20,25 @@ use base qw(Rex::Report::Base);
 
 our $REPORT_PATH = "./reports";
 
+my $report_name_generator = sub {
+  my $str = time();
+  return $str;
+};
+
+sub set_report_name {
+  my ( $class, $code ) = @_;
+
+  if ( ref $class eq "CODE" ) {
+    $code = $class;
+  }
+
+  if ( ref $code ne "CODE" ) {
+    die "Rex::Report::YAML->set_report_name(\$code_ref) wrong arguments.";
+  }
+
+  $report_name_generator = $code;
+}
+
 sub new {
   my $that  = shift;
   my $proto = ref($that) || $that;
@@ -46,8 +65,12 @@ sub write_report {
   if ( !-d $REPORT_PATH . "/" . $server_name ) {
     mkdir "$REPORT_PATH/$server_name";
   }
-  open( my $fh, ">", "$REPORT_PATH/$server_name/" . time() . ".yml" )
-    or die($!);
+  open(
+    my $fh,
+    ">",
+    "$REPORT_PATH/$server_name/"
+      . $report_name_generator->($server_name) . ".yml"
+  ) or die($!);
   print $fh Dump( $self->{__reports__} );
   close($fh);
 
